<?php
/**
 * Batch Mail a Card Export Class.
 *
 * @package     Give_Tributes
 * @subpackage  Give_Tributes/admin
 * @since       1.0.0
 */

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Give_Tributes_MailCard_Export Class
 *
 * @since 1.0
 */
class Give_Tributes_MailCard_Export extends Give_Batch_Export {

	/**
	 * Our export type. Used for export-type specific filters/actions.
	 *
	 * @var string
	 * @since 1.0
	 */
	public $export_type = 'mail-card';

	/**
	 * Form submission data
	 *
	 * @var array
	 * @since 1.0
	 */
	private $data = array();

	/**
	 * Set Total number of the Donation.
	 *
	 * @since 1.0
	 * @var int
	 */
	public $total_donation = 0;

	/**
	 * Set the properties specific to the donors export.
	 *
	 * @since 1.0
	 *
	 * @param array $request The Form Data passed into the batch processing.
	 */
	public function set_properties( $request ) {

		// Set data from form submission.
		if ( isset( $_POST['form'] ) ) {
			parse_str( $_POST['form'], $this->data );
		}

		$this->form = $this->data['forms'];
	}

	/**
	 * Set the CSV columns.
	 *
	 * @access public
	 * @since  1.0
	 * @return array|bool $cols All the columns.
	 */
	public function csv_cols() {

		$cols = $this->get_cols();

		return $cols;
	}

	/**
	 * CSV file columns.
	 *
	 * @return array
	 */
	private function get_cols() {

		$cols                       = array();
		$cols['donor_first_name']   = __( 'Donor First Name', 'give-tributes' );
		$cols['donor_last_name']    = __( 'Donor Last Name', 'give-tributes' );
		$cols['donor_email']        = __( 'Donor Email', 'give-tributes' );
		$cols['donor_address']      = __( 'Donor Address', 'give-tributes' );
		$cols['donor_address_2']    = __( 'Donor Address 2', 'give-tributes' );
		$cols['donor_city']         = __( 'Donor City', 'give-tributes' );
		$cols['donor_state']        = __( 'Donor State/Province', 'give-tributes' );
		$cols['donor_zip']          = __( 'Donor Zip', 'give-tributes' );
		$cols['donor_country']      = __( 'Donor Country', 'give-tributes' );
		$cols['donation_form']      = __( 'Donation Form', 'give-tributes' );
		$cols['honoree_first_name'] = __( 'Honoree First Name', 'give-tributes' );
		$cols['honoree_last_name']  = __( 'Honoree Last Name', 'give-tributes' );
		$cols['notify_first_name']  = __( 'Notification First Name', 'give-tributes' );
		$cols['notify_last_name']   = __( 'Notification Last Name', 'give-tributes' );
		$cols['honoree_address']    = __( 'Notification Address', 'give-tributes' );
		$cols['honoree_address_2']  = __( 'Notification Address 2', 'give-tributes' );
		$cols['honoree_city']       = __( 'Notification City', 'give-tributes' );
		$cols['honoree_state']      = __( 'Notification State/Province', 'give-tributes' );
		$cols['honoree_zip']        = __( 'Notification Zip', 'give-tributes' );
		$cols['honoree_country']    = __( 'Notification Country', 'give-tributes' );

		return $cols;
	}

	/**
	 * Get the Export Data
	 *
	 * @access public
	 * @since  1.0
	 *
	 * @return array $data The data for the CSV file.
	 */
	public function get_data() {
		$i = 0;

		$data   = array();

		// Export donors for a specific donation form and also within specified time-frame.
		$args = array(
			'output'  => 'payments',
			'number'  => 30,
			'page'    => $this->step,
			'orderby' => 'DESC',
			'order'   => 'id',
			'status'  => give_get_payment_status_keys(),
		);

		if ( ! empty( $this->form ) ) {
			$args['meta_key']   = '_give_payment_form_id';
			$args['meta_value'] = absint( $this->form );

		}

		// Check for date option filter.
		if ( ! empty( $this->data['mail_card_export_start_date'] ) || ! empty( $this->data['mail_card_export_end_date'] ) ) {
			$args['start_date'] = ! empty( $this->data['mail_card_export_start_date'] ) ? date( 'Y-n-d 00:00:00', strtotime( $this->data['mail_card_export_start_date'] ) ) : date( 'Y-n-d 23:59:59', '1970-1-01 00:00:00' );
			$args['end_date']   = ! empty( $this->data['mail_card_export_end_date'] ) ? date( 'Y-n-d 23:59:59', strtotime( $this->data['mail_card_export_end_date'] ) ) : date( 'Y-n-d 23:59:59', current_time( 'timestamp' ) );
		}

		// Set Mail a Card args.
		$args['meta_query'] = array(
			'relation' => 'AND',
			array(
				'key'     => '_give_tributes_accept',
				'value'   => 'yes',
				'compare' => '=',
			),
			array(
				'key'     => '_give_tributes_would_to',
				'value'   => 'send_mail_card',
				'compare' => '=',
			),
		);

		$payments_query       = new Give_Payments_Query( $args );
		$donations            = $payments_query->get_payments();
		$donations_count      = count( $donations );
		$this->total_donation = $donations_count;

		if ( $donations ) {
			/* @var Give_Payment $payment */
			foreach ( $donations as $donation ) {

				// Set address variable.
				$address = '';
				if ( isset( $donation->user_id ) && $donation->user_id > 0 ) {
					$address = give_get_donor_address( $donation->user_id );
				}

				$honoree_first_name = give_get_meta( $donation->ID, '_give_tributes_first_name', true );
				$honoree_first_name = ! empty( $honoree_first_name ) ? $honoree_first_name : '';

				$honoree_last_name = give_get_meta( $donation->ID, '_give_tributes_last_name', true );
				$honoree_last_name = ! empty( $honoree_last_name ) ? $honoree_last_name : '';

				$give_tributes_mail_card_notify_first_name = give_get_meta( $donation->ID, '_give_tributes_mail_card_notify_first_name', true );
				$give_tributes_mail_card_notify_first_name = ! empty( $give_tributes_mail_card_notify_first_name ) ? ucfirst( $give_tributes_mail_card_notify_first_name ) : '';

				$give_tributes_mail_card_notify_last_name = give_get_meta( $donation->ID, '_give_tributes_mail_card_notify_last_name', true );
				$give_tributes_mail_card_notify_last_name = ! empty( $give_tributes_mail_card_notify_last_name ) ? ucfirst( $give_tributes_mail_card_notify_last_name ) : '';

				$give_tributes_mail_card_address_1 = give_get_meta( $donation->ID, '_give_tributes_mail_card_address_1', true );
				$give_tributes_mail_card_address_1 = ! empty( $give_tributes_mail_card_address_1 ) ? $give_tributes_mail_card_address_1 : '';
				$give_tributes_mail_card_address_2 = give_get_meta( $donation->ID, '_give_tributes_mail_card_address_2', true );
				$give_tributes_mail_card_address_2 = ! empty( $give_tributes_mail_card_address_2 ) ? $give_tributes_mail_card_address_2 : '';
				$give_tributes_mail_card_city      = give_get_meta( $donation->ID, '_give_tributes_mail_card_city', true );
				$give_tributes_mail_card_city      = ! empty( $give_tributes_mail_card_city ) ? $give_tributes_mail_card_city : '';
				$give_tributes_address_state       = give_get_meta( $donation->ID, '_give_tributes_address_state', true );
				$give_tributes_address_state       = ! empty( $give_tributes_address_state ) ? $give_tributes_address_state : '';
				$give_tributes_mail_card_zipcode   = give_get_meta( $donation->ID, '_give_tributes_mail_card_zipcode', true );
				$give_tributes_mail_card_zipcode   = ! empty( $give_tributes_mail_card_zipcode ) ? $give_tributes_mail_card_zipcode : '';
				$give_tributes_address_country     = give_get_meta( $donation->ID, '_give_tributes_address_country', true );
				$give_tributes_address_country     = ! empty( $give_tributes_address_country ) ? $give_tributes_address_country : '';

				$data[] = array(
					'donor_first_name'   => $donation->first_name,
					'donor_last_name'    => $donation->last_name,
					'donor_email'        => $donation->email,
					'donor_address'      => isset( $address['line1'] ) ? $address['line1'] : '',
					'donor_address_2'    => isset( $address['line2'] ) ? $address['line2'] : '',
					'donor_city'         => isset( $address['city'] ) ? $address['city'] : '',
					'donor_state'        => isset( $address['state'] ) ? $address['state'] : '',
					'donor_zip'          => isset( $address['zip'] ) ? $address['zip'] : '',
					'donor_country'      => isset( $address['country'] ) ? $address['country'] : '',
					'donation_form'      => $donation->form_title,
					'honoree_first_name' => $honoree_first_name,
					'honoree_last_name'  => $honoree_last_name,
					'notify_first_name'  => $give_tributes_mail_card_notify_first_name,
					'notify_last_name'   => $give_tributes_mail_card_notify_last_name,
					'honoree_address'    => $give_tributes_mail_card_address_1,
					'honoree_address_2'  => $give_tributes_mail_card_address_2,
					'honoree_city'       => $give_tributes_mail_card_city,
					'honoree_state'      => $give_tributes_address_state,
					'honoree_zip'        => $give_tributes_mail_card_zipcode,
					'honoree_country'    => $give_tributes_address_country,
				);

				$i ++;
			}// End foreach().
		}// End if().

		$data = apply_filters( 'give_tribute_export_get_data', $data );
		$data = apply_filters( "give_tribute_export_get_data_{$this->export_type}", $data );

		return $data;
	}

	/**
	 * Return the calculated completion percentage.
	 *
	 * @since 1.0
	 *
	 * @return int
	 */
	public function get_percentage_complete() {

		$percentage = 0;
		$total      = $this->total_donation;

		if ( $total > 0 ) {
			$percentage = ( ( 30 * $this->step ) / $total ) * 100;
		}

		if ( $percentage > 100 ) {
			$percentage = 100;
		}

		return $percentage;
	}
}
